@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::PluginBundle::Author::KENTNL::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.1.1';
+  $Dist::Zilla::PluginBundle::Author::KENTNL::VERSION = '1.2.0';
 }
 
 # ABSTRACT: BeLike::KENTNL when you build your distributions.
@@ -95,25 +95,9 @@ sub _release_fail {
   return $ref;
 }
 
-sub _if_twitter {
-  my ( $args, $twitter, $else ) = @_;
-  return @{$twitter} if ( exists $ENV{KENTNL_TWITTER_ONLY} );
-  return @{$twitter} if ( exists $args->{twitter_only} );
-  return @{$else};
-}
-
-sub _if_git_versions {
-  my ( $args, $gitversions, $else ) = @_;
-  return @{$gitversions} if exists $ENV{KENTNL_GITVERSIONS};
-  return @{$gitversions} if exists $args->{git_versions};
-  return @{$else};
-}
-
 sub _params_list {
   return (
-    qw( :version authority auto_prereqs_skip git_versions twitter_only release_fail no_cpan no_git no_twitter twitter_hash_tags twitter_extra_hash_tags ),
-    ( map { 'version_' . $_ } qw( major minor ), ( map { 'rel_' . $_ } qw( year month day hour time_zone ) ) ),
-    qw( release_fail )
+    qw( :version authority auto_prereqs_skip git_versions twitter_only release_fail no_cpan no_git no_twitter twitter_hash_tags twitter_extra_hash_tags release_fail )
   );
 }
 
@@ -136,25 +120,27 @@ sub _param_checker {
 
 sub mvp_multivalue_args { return qw( auto_prereqs_skip ) }
 
-sub bundle_config {
-  my ( $self, $section ) = @_;
-  my $class = ( ref $self ) || $self;
-
-  my $arg = $section->{payload};
+sub bundle_config_inner {
+  my ( $class, $arg ) = @_;
 
   ## no critic (RequireInterpolationOfMetachars)
   my $twitter_conf = {
     hash_tags => _defined_or( $arg, twitter_hash_tags => '#perl #cpan' ),
     tweet_url => 'https://metacpan.org/source/{{$AUTHOR_UC}}/{{$DIST}}-{{$VERSION}}{{$TRIAL}}/Changes',
   };
+
   my $extra_hash = _defined_or( $arg, twitter_extra_hash_tags => q{}, 1 );
   $twitter_conf->{hash_tags} .= q{ } . $extra_hash if $extra_hash;
-  my $warn_no_git = _if_git_versions( $arg, [1], [0] );
 
-  my $checker = $self->_param_checker;
+  if ( not exists $arg->{git_versions} ) {
+    require Carp;
+    Carp::croak('Sorry, Git based versions are now mandatory');
+  }
+
+  my $checker = $class->_param_checker;
 
   for my $param ( keys %{$arg} ) {
-    $checker->( $self, $param );
+    $checker->( $class, $param );
   }
 
   if ( not defined $arg->{authority} ) {
@@ -169,39 +155,37 @@ sub bundle_config {
     Carp::carp('[Author::KENTNL] auto_prereqs_skip is expected to be an array ref');
   }
 
-  my @config = map { _expand( $class, $_->[0], $_->[1] ) } (
-    [
-      _if_git_versions(
-        $arg,
-        [ 'Git::NextVersion' => { version_regexp => '^(.*)-source$', first_version => '0.1.0' } ],
-        [
-          'AutoVersion::Relative' => {
-            major     => _defined_or( $arg, version_major         => 0,                  $warn_no_git ),
-            minor     => _defined_or( $arg, version_minor         => 1,                  $warn_no_git ),
-            year      => _defined_or( $arg, version_rel_year      => 2010,               $warn_no_git ),
-            month     => _defined_or( $arg, version_rel_month     => 5,                  $warn_no_git ),
-            day       => _defined_or( $arg, version_rel_day       => 16,                 $warn_no_git ),
-            hour      => _defined_or( $arg, version_rel_hour      => 20,                 $warn_no_git ),
-            time_zone => _defined_or( $arg, version_rel_time_zone => 'Pacific/Auckland', $warn_no_git ),
-          }
-        ]
-      )
-    ],
-    [ 'GatherDir'  => { include_dotfiles => 1 } ],
+  my (@version) = ( [ 'Git::NextVersion' => { version_regexp => '^(.*)-source$', first_version => '0.1.0' } ], );
+  my (@metadata) = (
     [ 'MetaConfig' => {} ],
-    [ 'PruneCruft' => { except           => '^.perltidyrc' } ],
     _only_git( $arg, [ 'GithubMeta' => {} ] ),
-    [ 'License'               => {} ],
-    [ 'PkgVersion'            => {} ],
-    [ 'Authority'             => { authority => $arg->{authority}, do_metadata => 1 } ],
-    [ 'PodWeaver'             => {} ],
     [ 'MetaProvides::Package' => {} ],
-    [ 'MetaJSON'              => {} ],
-    [ 'MetaYAML'              => {} ],
-    [ 'ModuleBuild'           => {} ],
-    [ 'ReadmeFromPod'         => {} ],
-    [ 'ManifestSkip'          => {} ],
-    [ 'Manifest'              => {} ],
+    [ 'MetaData::BuiltWith'   => { $^O eq 'linux' ? ( show_uname => 1, uname_args => q{ -s -o -r -m -i } ) : () } ],
+
+  );
+
+  my (@sharedir) = ();
+
+  my (@gatherfiles) = (
+    [ 'GatherDir'            => { include_dotfiles    => 1 } ],
+    [ 'License'              => {} ],
+    [ 'MetaJSON'             => {} ],
+    [ 'MetaYAML'             => {} ],
+    [ 'Manifest'             => {} ],
+    [ 'MetaTests'            => {} ],
+    [ 'PodCoverageTests'     => {} ],
+    [ 'PodSyntaxTests'       => {} ],
+    [ 'ReportVersions::Tiny' => {} ],
+    [ 'Test::Kwalitee'       => {} ],
+    [ 'EOLTests'             => { trailing_whitespace => 1, } ],
+    [ 'Test::MinimumVersion' => {} ],
+    [ 'Test::Compile'        => {} ],
+    [ 'Test::Perl::Critic'   => {} ],
+  );
+
+  my (@prunefiles) = ( [ 'PruneCruft' => { except => '^.perltidyrc' } ], [ 'ManifestSkip' => {} ], );
+
+  my (@regprereqs) = (
     [ 'AutoPrereqs' => { skip => $arg->{auto_prereqs_skip} } ],
     [
       'Prereqs' => {
@@ -224,43 +208,54 @@ sub bundle_config {
         -name                                       => 'BundleDevelSuggests',
         -phase                                      => 'develop',
         -type                                       => 'suggests',
-        'Dist::Zilla::PluginBundle::Author::KENTNL' => '1.1.0',
+        'Dist::Zilla::PluginBundle::Author::KENTNL' => '1.2.0',
       }
     ],
     [ 'Author::KENTNL::MinimumPerl' => {} ],
-    [ 'Test::MinimumVersion'        => {} ],
-    [ 'MetaData::BuiltWith'         => { $^O eq 'linux' ? ( show_uname => 1, uname_args => q{ -s -o -r -m -i } ) : () } ],
-    [ 'Test::CPAN::Changes'         => {} ],
-    [ 'Test::Compile'               => {} ],
-    [ 'Test::Perl::Critic'          => {} ],
-    [ 'MetaTests'                   => {} ],
-    [ 'PodCoverageTests'            => {} ],
-    [ 'PodSyntaxTests'              => {} ],
-    [ 'ReportVersions::Tiny'        => {} ],
-    [ 'Test::Kwalitee'              => {} ],
-    [ 'EOLTests'        => { trailing_whitespace => 1, } ],
-    [ 'CheckExtraTests' => {} ],
-    [ 'TestRelease'     => {} ],
-    [ 'ConfirmRelease'  => {} ],
-    _if_twitter(
-      $arg,
-      [ [ 'FakeRelease' => { user => 'KENTNL' }, ], [ 'Twitter' => $twitter_conf, ], ],
-      [
-        _release_fail($arg),
-        _only_git( $arg, [ 'Git::Check' => { filename => 'Changes' } ] ),
-        [ 'NextRelease' => { time_zone => 'UTC', format => q[%v %{yyyy-MM-dd'T'HH:mm:ss}dZ] } ],
-        _only_git( $arg, [ [ 'Git::Tag', 'tag_master' ] => { tag_format => '%v-source' } ] ),
-        _only_git( $arg, [ 'Git::Commit' => {} ] ),
-        _only_git( $arg, [ 'Git::CommitBuild' => { release_branch => 'releases' } ] ),
-        _only_git( $arg, [ [ 'Git::Tag', 'tag_release' ] => { branch => 'releases', tag_format => '%v' } ] ),
-        _only_cpan( $arg, [ 'UploadToCPAN' => {} ] ),
-        _only_cpan( $arg, _only_twitter( $arg, [ 'Twitter' => $twitter_conf ] ) ),
-      ]
-    )
   );
+  my (@mungers) = (
+    [ 'PkgVersion'  => {} ],
+    [ 'PodWeaver'   => {} ],
+    [ 'NextRelease' => { time_zone => 'UTC', format => q[%v %{yyyy-MM-dd'T'HH:mm:ss}dZ] } ],
+  );
+
+  return (
+    @version,
+    @metadata,
+    @sharedir,
+    @gatherfiles,
+    @prunefiles,
+    @mungers,
+    @regprereqs,
+    [ 'Authority'           => { authority => $arg->{authority}, do_metadata => 1 } ],
+    [ 'ModuleBuild'         => {} ],
+    [ 'ReadmeFromPod'       => {} ],
+    [ 'Test::CPAN::Changes' => {} ],
+    [ 'CheckExtraTests'     => {} ],
+    [ 'TestRelease'         => {} ],
+    [ 'ConfirmRelease'      => {} ],
+    _release_fail($arg),
+    _only_git( $arg, [ 'Git::Check' => { filename => 'Changes' } ] ),
+    _only_git( $arg, [ [ 'Git::Tag', 'tag_master' ] => { tag_format => '%v-source' } ] ),
+    _only_git( $arg, [ 'Git::Commit' => {} ] ),
+    _only_git( $arg, [ 'Git::CommitBuild' => { release_branch => 'releases' } ] ),
+    _only_git( $arg, [ [ 'Git::Tag', 'tag_release' ] => { branch => 'releases', tag_format => '%v' } ] ),
+    _only_cpan( $arg, [ 'UploadToCPAN' => {} ] ),
+    [ 'Twitter' => $twitter_conf ],
+  );
+}
+
+sub bundle_config {
+  my ( $self, $section ) = @_;
+  my $class = ( ref $self ) || $self;
+
+  my $arg = $section->{payload};
+
+  my @config = map { _expand( $class, $_->[0], $_->[1] ) } $class->bundle_config_inner($arg);
   load_class( $_->[1] ) for @config;
   return @config;
 }
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
@@ -279,15 +274,14 @@ Dist::Zilla::PluginBundle::Author::KENTNL - BeLike::KENTNL when you build your d
 
 =head1 VERSION
 
-version 1.1.1
+version 1.2.0
 
 =head1 SYNOPSIS
 
     [@Author::KENTNL]
     no_cpan = 1 ; skip upload to cpan and twitter.
     no_git  = 1 ; skip things that work with git.
-    twitter_only = 1 ; skip uploading to cpan, don't git, but twitter with fakerelease.
-    release_fail = 1 ; asplode!. ( non-twitter only )
+    release_fail = 1 ; asplode!.
     git_versions = 1 ;  use git::nextversion for versioning
 
 =head1 DESCRIPTION
@@ -366,15 +360,12 @@ the same as no_git=1
 
 same as no_cpan = 1
 
-=head2 KENTNL_TWITTER_ONLY
-
-same as twitter_only=1
-
 =head2 KENTNL_RELEASE_FAIL
 
 same as release_fail=1
 
 =for Pod::Coverage   mvp_multivalue_args
+  bundle_config_inner
 
 =head1 AUTHOR
 
